Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(49)

Unified Diff: include/v8-debug.h

Issue 100158: Create a transition API for the debug message handler (Closed) Base URL: http://v8.googlecode.com/svn/branches/bleeding_edge/
Patch Set: Created 11 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/api.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/v8-debug.h
===================================================================
--- include/v8-debug.h (revision 1813)
+++ include/v8-debug.h (working copy)
@@ -162,14 +162,27 @@
*
* \param message the debug message handler message object
* \param length length of the message
* \param data the data value passed when registering the message handler
* A MessageHandler does not take posession of the message string,
* and must not rely on the data persisting after the handler returns.
+ *
+ * This message handler is deprecated. Use MessageHandler2 instead.
*/
- typedef void (*MessageHandler)(const Message& message);
+ typedef void (*MessageHandler)(const uint16_t* message, int length,
+ ClientData* client_data);
/**
+ * Debug message callback function.
+ *
+ * \param message the debug message handler message object
+
+ * A MessageHandler does not take posession of the message data,
+ * and must not rely on the data persisting after the handler returns.
+ */
+ typedef void (*MessageHandler2)(const Message& message);
+
+ /**
* Debug host dispatch callback function.
*/
typedef void (*HostDispatchHandler)();
@@ -189,6 +202,7 @@
// handler thread is not supported any more parameter must be false.
static void SetMessageHandler(MessageHandler handler,
bool message_handler_thread = false);
+ static void SetMessageHandler2(MessageHandler2 handler);
yurys 2009/04/29 12:36:08 When all clients are switched to the new message h
Søren Thygesen Gjesse 2009/04/29 13:24:15 I agree that this is not optimal, but we need to k
static void SendCommand(const uint16_t* command, int length,
@@ -162,14 +162,27 @@
* \param message the debug message handler message object
* \param length length of the message
- * \param data the data value passed when registering the message handler
+ * \param client_data the data value passed when registering the message handler
* A MessageHandler does not take posession of the message string,
* and must not rely on the data persisting after the handler returns.
ClientData* client_data = NULL);
« no previous file with comments | « no previous file | src/api.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698